==> darwin-shared-0.2.37.tar.gz: darwin-shared-0.2.37/darwin/utils/cpf.py <==
from re import sub, match


class Cpf:

    regex = r"^\d{3}.\d{3}.\d{3}-\d{2}$"

    def __init__(self, numbers):
        self.numbers = numbers

    def unformatted(self):
        return sub(r"\D", "", self.numbers)

    def formatted(self):
        numbers = self.numbers
        isNumberPattern = match(r"^[0-9]{11}$", numbers)
        cpfPattern = "{0}.{1}.{2}-{3}"
        return cpfPattern.format(numbers[:3], numbers[3:6], numbers[6:9], numbers[9:11]) if isNumberPattern else numbers

    def matchPattern(self, pattern=None):
        return match(pattern or Cpf.regex, self.numbers)

    def isValid(self, pattern=None):

        if not self.matchPattern(pattern or Cpf.regex): return False

        cpf = self.unformatted()

        if len(cpf) != 11: return False

        if cpf in [
            "00000000000",
            "11111111111",
            "22222222222",
            "33333333333",
            "44444444444",
            "55555555555",
            "66666666666",
            "77777777777",
            "88888888888",
            "99999999999"
        ]: return False

        if self.__remainder(self.__sum(string=cpf, until=10)) != int(cpf[9]): return False

        if self.__remainder(self.__sum(string=cpf, until=11)) != int(cpf[10]): return False

        return True

    def __sum(self, string, until):
        result = 0
        for i in range(1, until):
            result = result + int(string[i-1]) * (until + 1 - i)
        return result

    def __remainder(self, sum):
        result = (sum * 10) % 11
        if result == 10 or result == 11: result = 0
        return result

==> darwin-shared-v2-0.3.0.tar.gz: darwin-shared-v2-0.3.0/darwin/utils/cpf.py <==
from re import sub, match


class Cpf:

    regex = r"^\d{11}$|^\d{3}\.\d{3}\.\d{3}-\d{2}$"

    def __init__(self, numbers):
        self.numbers = numbers

    def unformatted(self):
        return sub(r"\D", "", self.numbers)

    def formatted(self):
        numbers = self.numbers
        isNumberPattern = match(Cpf.regex, numbers)
        cpfPattern = "{0}.{1}.{2}-{3}"
        return cpfPattern.format(numbers[:3], numbers[3:6], numbers[6:9], numbers[9:11]) if isNumberPattern else numbers

    def matchPattern(self, pattern=None):
        return match(pattern or Cpf.regex, self.numbers)

    def isValid(self, pattern=None):

        if not self.matchPattern(pattern or Cpf.regex): return False

        cpf = self.unformatted()

        if len(cpf) != 11: return False

        if cpf in [
            "00000000000",
            "11111111111",
            "22222222222",
            "33333333333",
            "44444444444",
            "55555555555",
            "66666666666",
            "77777777777",
            "88888888888",
            "99999999999"
        ]: return False

        if self.__remainder(self.__sum(string=cpf, until=10)) != int(cpf[9]): return False

        if self.__remainder(self.__sum(string=cpf, until=11)) != int(cpf[10]): return False

        return True

    def __sum(self, string, until):
        result = 0
        for i in range(1, until):
            result = result + int(string[i - 1]) * (until + 1 - i)
        return result

    def __remainder(self, sum):
        result = (sum * 10) % 11
        if result == 10 or result == 11: result = 0
        return result
